package test;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.SQLException;

/** test insertion of unicode into mysql DB.  */
public class UnicodeTest {

    // http://www.fileformat.info/info/unicode/char/12097/index.htm
    final String _uc = "\uD808\uDC97";

    /** connect to mysql db */
    protected Connection db_connect( String ip_address,
		String username, String password, String database ) 
	    	throws SQLException{
	Connection conn = null;
	String driver = "jdbc:mysql";
	String ip = ip_address;
	String port = "3306";
	String conn_str = null;

	DriverManager.registerDriver( new com.mysql.jdbc.Driver() );

	// build the connection string and connect to the db
	conn_str = driver + ":" + "//" + ip + ":" + port +"/" + database +
                "?useUnicode=true&characterEncoding=utf8" +
                "&user=" + username + "&password=" + password ;

	conn = DriverManager.getConnection( conn_str );
	conn.setAutoCommit( false );
	return conn;
    }

   /** send the passed text into the database */
   private void insert( Connection conn, String text, String database ) 
		throws java.sql.SQLException {

	if ( conn == null ){
		throw new IllegalArgumentException("UnicodeTest::insert():passed database connection is invalid!");
	}
	if ( database == null ){
		throw new IllegalArgumentException("UnicodeTest::insert():passed database name is invalid!");
	}
	PreparedStatement ps =  null;
	final String sql = 
		"insert	into " + database + ".unicode_test( text ) " +
		"values ( ? ) ";
	try {
		ps = conn.prepareStatement( sql );
		ps.setString( 1, text );
		ps.executeUpdate();		// perform work
	}
	catch ( java.sql.SQLException e ){
		System.err.println( "UnicodeTest::insert():error inserting unicode into table! " );
		throw e;
	}
	finally {
		if ( ps != null ){
			try {
				ps.close();
			}
			catch( Exception e ){}
		}
	}
   }

   /** 
    * @param dbpedia_file_name name of dbpedia short abstract file
    */
   public void load( String ip_address,
		String username, String password, String database ){

	Connection conn = null;

	if ( ( ip_address == null ) || (ip_address.equals("")) ){
		throw new IllegalArgumentException("UnicodeTest::load(): passed IP Address is null!");
	}
	if ( ( username == null ) || (username.equals("")) ){
		throw new IllegalArgumentException("UnicodeTest::load(): passed username is null!");
	}

	try {
		// connect to DB here
		conn = db_connect( ip_address, username, password, database ); 

		insert( conn, _uc, database ); 	// insert the string
		conn.commit();
	} 
	catch(  java.sql.SQLException e ){
		System.err.println( e );
		if ( conn != null ){
			System.err.println( "attempting database rollback." );
			try {
				conn.rollback();
				System.err.println( "rollback successful." );
			}
			catch ( Exception ex ){}
		}
	}
	finally {
		if ( conn != null ){
			try {
				conn.close();
			}
			catch ( java.sql.SQLException e ){}
		}
	}
   }

   /** send caller a program usage message */
   public void usage() {
	System.out.println();
	System.out.println("\tUsage: java " + this.getClass().getName() +
		" [ ip_address username password database ] ");
	System.out.println();
   }

   public static void main ( String argv[] ){
	UnicodeTest app = new UnicodeTest();
	if ( argv.length < 4 ){
		app.usage();
		System.exit(0);
	} 
	app.load( argv[0], argv[1], argv[2], argv[3] );
   }
}

